pub fn differential_test<A, B, T>(
inputs: &[(String, Vec<u8>)],
impl_a: A,
impl_b: B,
) -> Vec<DiffResult<T>>Expand description
Run a differential comparison between two functions over a set of byte-vector inputs.
pub fn differential_test<A, B, T>(
inputs: &[(String, Vec<u8>)],
impl_a: A,
impl_b: B,
) -> Vec<DiffResult<T>>Run a differential comparison between two functions over a set of byte-vector inputs.